@@ -1,8 +1,8 @@
 context("Style")
 
 test_that("Package Style", {
-
-  lintr::expect_lint_free(linters = list(
+  if (requireNamespace("lintr", quietly = TRUE)) {
+    lintr::expect_lint_free(linters = list(
     a = lintr::assignment_linter,
     b = lintr::commas_linter,
     # c = lintr::commented_code_linter,
@@ -11,6 +11,6 @@ test_that("Package Style", {
     f = lintr::no_tab_linter,
     h = lintr::object_length_linter(25L),
     i = lintr::spaces_left_parentheses_linter
-  ))
-  
+    ))
+  }
 })
